Class: DyspatchClient::CompiledRead
- Inherits:
-
Object
- Object
- DyspatchClient::CompiledRead
- Defined in:
- lib/dyspatch_client/models/compiled_read.rb
Instance Attribute Summary collapse
-
#html ⇒ Object
Base64 encoded template HTML body.
-
#reply_to ⇒ Object
Reply-To address.
-
#sender ⇒ Object
Sender address.
-
#subject ⇒ Object
Base64 encoded template subject line.
-
#text ⇒ Object
Base64 encoded template text body.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CompiledRead
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CompiledRead
Initializes the object
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/dyspatch_client/models/compiled_read.rb', line 56 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'sender') self.sender = attributes[:'sender'] end if attributes.has_key?(:'replyTo') self.reply_to = attributes[:'replyTo'] end if attributes.has_key?(:'subject') self.subject = attributes[:'subject'] end if attributes.has_key?(:'html') self.html = attributes[:'html'] end if attributes.has_key?(:'text') self.text = attributes[:'text'] end end |
Instance Attribute Details
#html ⇒ Object
Base64 encoded template HTML body
27 28 29 |
# File 'lib/dyspatch_client/models/compiled_read.rb', line 27 def html @html end |
#reply_to ⇒ Object
Reply-To address
21 22 23 |
# File 'lib/dyspatch_client/models/compiled_read.rb', line 21 def reply_to @reply_to end |
#sender ⇒ Object
Sender address
18 19 20 |
# File 'lib/dyspatch_client/models/compiled_read.rb', line 18 def sender @sender end |
#subject ⇒ Object
Base64 encoded template subject line
24 25 26 |
# File 'lib/dyspatch_client/models/compiled_read.rb', line 24 def subject @subject end |
#text ⇒ Object
Base64 encoded template text body
30 31 32 |
# File 'lib/dyspatch_client/models/compiled_read.rb', line 30 def text @text end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 |
# File 'lib/dyspatch_client/models/compiled_read.rb', line 33 def self.attribute_map { :'sender' => :'sender', :'reply_to' => :'replyTo', :'subject' => :'subject', :'html' => :'html', :'text' => :'text' } end |
.swagger_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 50 51 52 |
# File 'lib/dyspatch_client/models/compiled_read.rb', line 44 def self.swagger_types { :'sender' => :'String', :'reply_to' => :'String', :'subject' => :'String', :'html' => :'String', :'text' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
143 144 145 146 147 148 149 150 151 |
# File 'lib/dyspatch_client/models/compiled_read.rb', line 143 def ==(o) return true if self.equal?(o) self.class == o.class && sender == o.sender && reply_to == o.reply_to && subject == o.subject && html == o.html && text == o.text end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/dyspatch_client/models/compiled_read.rb', line 189 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = DyspatchClient.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/dyspatch_client/models/compiled_read.rb', line 255 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/dyspatch_client/models/compiled_read.rb', line 168 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
155 156 157 |
# File 'lib/dyspatch_client/models/compiled_read.rb', line 155 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
161 162 163 |
# File 'lib/dyspatch_client/models/compiled_read.rb', line 161 def hash [sender, reply_to, subject, html, text].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/dyspatch_client/models/compiled_read.rb', line 85 def list_invalid_properties invalid_properties = Array.new if !@subject.nil? && @subject !~ Regexp.new(/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/) invalid_properties.push('invalid value for "subject", must conform to the pattern /^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/.') end if !@html.nil? && @html !~ Regexp.new(/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/) invalid_properties.push('invalid value for "html", must conform to the pattern /^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/.') end if !@text.nil? && @text !~ Regexp.new(/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/) invalid_properties.push('invalid value for "text", must conform to the pattern /^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
235 236 237 |
# File 'lib/dyspatch_client/models/compiled_read.rb', line 235 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
241 242 243 244 245 246 247 248 249 |
# File 'lib/dyspatch_client/models/compiled_read.rb', line 241 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
229 230 231 |
# File 'lib/dyspatch_client/models/compiled_read.rb', line 229 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
104 105 106 107 108 109 |
# File 'lib/dyspatch_client/models/compiled_read.rb', line 104 def valid? return false if !@subject.nil? && @subject !~ Regexp.new(/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/) return false if !@html.nil? && @html !~ Regexp.new(/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/) return false if !@text.nil? && @text !~ Regexp.new(/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/) true end |