Class: DyspatchClient::TemplatesApi
- Inherits:
-
Object
- Object
- DyspatchClient::TemplatesApi
- Defined in:
- lib/dyspatch_client/api/templates_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_template_by_id(template_id, target_language, accept, opts = {}) ⇒ TemplateRead
Get Template by ID Gets a template object with the matching ID.
-
#get_template_by_id_with_http_info(template_id, target_language, accept, opts = {}) ⇒ Array<(TemplateRead, Integer, Hash)>
Get Template by ID Gets a template object with the matching ID.
-
#get_templates(accept, opts = {}) ⇒ TemplatesRead
List Templates Gets a list of Template Metadata objects for all templates.
-
#get_templates_with_http_info(accept, opts = {}) ⇒ Array<(TemplatesRead, Integer, Hash)>
List Templates Gets a list of Template Metadata objects for all templates.
-
#initialize(api_client = ApiClient.default) ⇒ TemplatesApi
constructor
A new instance of TemplatesApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ TemplatesApi
Returns a new instance of TemplatesApi.
19 20 21 |
# File 'lib/dyspatch_client/api/templates_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/dyspatch_client/api/templates_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_template_by_id(template_id, target_language, accept, opts = {}) ⇒ TemplateRead
Get Template by ID Gets a template object with the matching ID. If the template has published content the "compiled" field will contain the template .
29 30 31 32 |
# File 'lib/dyspatch_client/api/templates_api.rb', line 29 def get_template_by_id(template_id, target_language, accept, opts = {}) data, _status_code, _headers = get_template_by_id_with_http_info(template_id, target_language, accept, opts) data end |
#get_template_by_id_with_http_info(template_id, target_language, accept, opts = {}) ⇒ Array<(TemplateRead, Integer, Hash)>
Get Template by ID Gets a template object with the matching ID. If the template has published content the "compiled" field will contain the template .
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/dyspatch_client/api/templates_api.rb', line 41 def get_template_by_id_with_http_info(template_id, target_language, accept, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TemplatesApi.get_template_by_id ...' end # verify the required parameter 'template_id' is set if @api_client.config.client_side_validation && template_id.nil? fail ArgumentError, "Missing the required parameter 'template_id' when calling TemplatesApi.get_template_by_id" end # verify the required parameter 'target_language' is set if @api_client.config.client_side_validation && target_language.nil? fail ArgumentError, "Missing the required parameter 'target_language' when calling TemplatesApi.get_template_by_id" end # verify enum value allowable_values = ["html", "handlebars", "ampscript", "freemarker", "cheetah", "jinja"] if @api_client.config.client_side_validation && !allowable_values.include?(target_language) fail ArgumentError, "invalid value for \"target_language\", must be one of #{allowable_values}" end # verify the required parameter 'accept' is set if @api_client.config.client_side_validation && accept.nil? fail ArgumentError, "Missing the required parameter 'accept' when calling TemplatesApi.get_template_by_id" end # resource path local_var_path = '/templates/{templateId}'.sub('{' + 'templateId' + '}', CGI.escape(template_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'targetLanguage'] = target_language # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.dyspatch.2020.04+json', '*/*']) header_params[:'Accept'] = accept # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'TemplateRead' # auth_names auth_names = opts[:auth_names] || ['Bearer'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TemplatesApi#get_template_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_templates(accept, opts = {}) ⇒ TemplatesRead
List Templates Gets a list of Template Metadata objects for all templates. Up to 25 results returned before results are paginated.
109 110 111 112 |
# File 'lib/dyspatch_client/api/templates_api.rb', line 109 def get_templates(accept, opts = {}) data, _status_code, _headers = get_templates_with_http_info(accept, opts) data end |
#get_templates_with_http_info(accept, opts = {}) ⇒ Array<(TemplatesRead, Integer, Hash)>
List Templates Gets a list of Template Metadata objects for all templates. Up to 25 results returned before results are paginated.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/dyspatch_client/api/templates_api.rb', line 120 def get_templates_with_http_info(accept, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TemplatesApi.get_templates ...' end # verify the required parameter 'accept' is set if @api_client.config.client_side_validation && accept.nil? fail ArgumentError, "Missing the required parameter 'accept' when calling TemplatesApi.get_templates" end # resource path local_var_path = '/templates' # query parameters query_params = opts[:query_params] || {} query_params[:'cursor'] = opts[:'cursor'] if !opts[:'cursor'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.dyspatch.2020.04+json', '*/*']) header_params[:'Accept'] = accept # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'TemplatesRead' # auth_names auth_names = opts[:auth_names] || ['Bearer'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TemplatesApi#get_templates\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |