Class: DyspatchClient::LocalizationsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/dyspatch_client/api/localizations_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ LocalizationsApi

Returns a new instance of LocalizationsApi.



19
20
21
# File 'lib/dyspatch_client/api/localizations_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/dyspatch_client/api/localizations_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#get_localization_by_id(localization_id, target_language, accept, opts = {}) ⇒ LocalizationRead

Get Localization Object by ID Returns a specific localization object with a matching ID

Parameters:

  • localization_id (String)

    A localization ID

  • target_language (String)

    The type of templating language to compile as. Should only be used for visual templates.

  • accept (String)

    A version of the API that should be used for the request. For example, to use version "2019.10", set the value to "application/vnd.dyspatch.2019.10+json"

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



29
30
31
32
# File 'lib/dyspatch_client/api/localizations_api.rb', line 29

def get_localization_by_id(localization_id, target_language, accept, opts = {})
  data, _status_code, _headers = get_localization_by_id_with_http_info(localization_id, target_language, accept, opts)
  data
end

#get_localization_by_id_with_http_info(localization_id, target_language, accept, opts = {}) ⇒ Array<(LocalizationRead, Integer, Hash)>

Get Localization Object by ID Returns a specific localization object with a matching ID

Parameters:

  • localization_id (String)

    A localization ID

  • target_language (String)

    The type of templating language to compile as. Should only be used for visual templates.

  • accept (String)

    A version of the API that should be used for the request. For example, to use version &quot;2019.10&quot;, set the value to &quot;application/vnd.dyspatch.2019.10+json&quot;

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(LocalizationRead, Integer, Hash)>)

    LocalizationRead data, response status code and response headers



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/dyspatch_client/api/localizations_api.rb', line 41

def get_localization_by_id_with_http_info(localization_id, target_language, accept, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: LocalizationsApi.get_localization_by_id ...'
  end
  # verify the required parameter 'localization_id' is set
  if @api_client.config.client_side_validation && localization_id.nil?
    fail ArgumentError, "Missing the required parameter 'localization_id' when calling LocalizationsApi.get_localization_by_id"
  end
  # verify the required parameter 'target_language' is set
  if @api_client.config.client_side_validation && target_language.nil?
    fail ArgumentError, "Missing the required parameter 'target_language' when calling LocalizationsApi.get_localization_by_id"
  end
  # verify enum value
  allowable_values = ["html", "handlebars", "ampscript", "freemarker", "cheetah"]
  if @api_client.config.client_side_validation && !allowable_values.include?(target_language)
    fail ArgumentError, "invalid value for \"target_language\", must be one of #{allowable_values}"
  end
  # verify the required parameter 'accept' is set
  if @api_client.config.client_side_validation && accept.nil?
    fail ArgumentError, "Missing the required parameter 'accept' when calling LocalizationsApi.get_localization_by_id"
  end
  # resource path
  local_var_path = '/localizations/{localizationId}'.sub('{' + 'localizationId' + '}', CGI.escape(localization_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'targetLanguage'] = target_language

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/vnd.dyspatch.2019.10+json', '*/*'])
  header_params[:'Accept'] = accept

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'LocalizationRead' 

  # auth_names
  auth_names = opts[:auth_names] || ['Bearer']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: LocalizationsApi#get_localization_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end