Class: DyspatchClient::TemplatesApi
- Inherits:
-
Object
- Object
- DyspatchClient::TemplatesApi
- Defined in:
- lib/dyspatch_client/api/templates_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ TemplatesApi
constructor
A new instance of TemplatesApi.
-
#templates_get(accept, opts = {}) ⇒ TemplatesRead
List Templates Gets a list of Template Metadata objects for all templates.
-
#templates_get_with_http_info(accept, opts = {}) ⇒ Array<(TemplatesRead, Fixnum, Hash)>
List Templates Gets a list of Template Metadata objects for all templates.
-
#templates_template_id_get(template_id, accept, opts = {}) ⇒ TemplateRead
Get Template by ID Gets a template object with the matching ID.
-
#templates_template_id_get_with_http_info(template_id, accept, opts = {}) ⇒ Array<(TemplateRead, Fixnum, Hash)>
Get Template by ID Gets a template object with the matching ID.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ TemplatesApi
Returns a new instance of TemplatesApi.
19 20 21 |
# File 'lib/dyspatch_client/api/templates_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/dyspatch_client/api/templates_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#templates_get(accept, opts = {}) ⇒ TemplatesRead
List Templates Gets a list of Template Metadata objects for all templates. Up to 25 results returned before results are paginated.
29 30 31 32 |
# File 'lib/dyspatch_client/api/templates_api.rb', line 29 def templates_get(accept, opts = {}) data, _status_code, _headers = templates_get_with_http_info(accept, opts) return data end |
#templates_get_with_http_info(accept, opts = {}) ⇒ Array<(TemplatesRead, Fixnum, Hash)>
List Templates Gets a list of Template Metadata objects for all templates. Up to 25 results returned before results are paginated.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/dyspatch_client/api/templates_api.rb', line 40 def templates_get_with_http_info(accept, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: TemplatesApi.templates_get ..." end # verify the required parameter 'accept' is set if @api_client.config.client_side_validation && accept.nil? fail ArgumentError, "Missing the required parameter 'accept' when calling TemplatesApi.templates_get" end # resource path local_var_path = "/templates" # query parameters query_params = {} query_params[:'cursor'] = opts[:'cursor'] if !opts[:'cursor'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.dyspatch.2018.08+json']) header_params[:'Accept'] = accept # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['Bearer'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'TemplatesRead') if @api_client.config.debugging @api_client.config.logger.debug "API called: TemplatesApi#templates_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#templates_template_id_get(template_id, accept, opts = {}) ⇒ TemplateRead
Get Template by ID Gets a template object with the matching ID. If the template has published content the "compiled" field will contain the template .
86 87 88 89 |
# File 'lib/dyspatch_client/api/templates_api.rb', line 86 def templates_template_id_get(template_id, accept, opts = {}) data, _status_code, _headers = templates_template_id_get_with_http_info(template_id, accept, opts) return data end |
#templates_template_id_get_with_http_info(template_id, accept, opts = {}) ⇒ Array<(TemplateRead, Fixnum, Hash)>
Get Template by ID Gets a template object with the matching ID. If the template has published content the "compiled" field will contain the template .
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/dyspatch_client/api/templates_api.rb', line 97 def templates_template_id_get_with_http_info(template_id, accept, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: TemplatesApi.templates_template_id_get ..." end # verify the required parameter 'template_id' is set if @api_client.config.client_side_validation && template_id.nil? fail ArgumentError, "Missing the required parameter 'template_id' when calling TemplatesApi.templates_template_id_get" end # verify the required parameter 'accept' is set if @api_client.config.client_side_validation && accept.nil? fail ArgumentError, "Missing the required parameter 'accept' when calling TemplatesApi.templates_template_id_get" end # resource path local_var_path = "/templates/{templateId}".sub('{' + 'templateId' + '}', template_id.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.dyspatch.2018.08+json']) header_params[:'Accept'] = accept # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['Bearer'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'TemplateRead') if @api_client.config.debugging @api_client.config.logger.debug "API called: TemplatesApi#templates_template_id_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |